@@ -258,8 +258,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // as the order of the headers in the CSV file is not guaranteed to be the same as the order of
     // the keys in the JSON object
     let temp_dir = env::temp_dir();
-    let intermediate_csv = temp_dir
-        .join("intermediate.csv")
+    let intermediate_csv = tempfile::Builder::new()
+        .suffix(".csv")
+        .tempfile_in(&temp_dir)?
+        .into_temp_path()
         .to_string_lossy()
         .into_owned();
 
@@ -275,22 +277,39 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
         let flattener = Flattener::new();
         let intermediate_csv_writer = csv::WriterBuilder::new()
-            .buffer_capacity(config::DEFAULT_WTR_BUFFER_CAPACITY)
+            .has_headers(true)
             .from_path(intermediate_csv.clone())?;
-        Json2Csv::new(flattener).convert_from_array(values, intermediate_csv_writer)?;
+        Json2Csv::new(flattener)
+            .preserve_key_order(true)
+            .convert_from_array(values, intermediate_csv_writer)?;
     }
 
     // STEP 2: select the columns to use in the final output
-    // if --select is not specified, select in the order of the first dict's keys
-    // safety: we checked that first_dict is not empty so headers is not empty
-    let sel_cols = args
-        .flag_select
-        .unwrap_or_else(|| SelectColumns::parse(&first_dict_headers.join(",")).unwrap());
-
+    // Read the intermediate CSV to get the actual headers (which are sorted alphabetically)
     let sel_rconfig = config::Config::new(Some(intermediate_csv).as_ref()).no_headers(false);
     let mut intermediate_csv_rdr = sel_rconfig.reader()?;
     let byteheaders = intermediate_csv_rdr.byte_headers()?;
 
+    // Convert byte headers to string headers for easier processing
+    let actual_headers: Vec<String> = byteheaders
+        .iter()
+        .map(|h| String::from_utf8_lossy(h).to_string())
+        .collect();
+
+    // If --select is not specified, reorder the actual headers to match the first dict's key order
+    let sel_cols = args.flag_select.unwrap_or_else(|| {
+        // If all expected headers exist, use the original order
+        if first_dict_headers
+            .iter()
+            .all(|&h| actual_headers.contains(&h.to_string()))
+        {
+            SelectColumns::parse(&first_dict_headers.join(",")).unwrap()
+        } else {
+            // Otherwise, just use the headers as they appear in the CSV
+            SelectColumns::parse(&actual_headers.join(",")).unwrap()
+        }
+    });
+
     // and write the selected columns to the final CSV file
     let sel = sel_rconfig.select(sel_cols).selection(byteheaders)?;
     let mut read_record = csv::ByteRecord::new();
