@@ -48,6 +48,14 @@ Examples:
 
     qsv split splitoutdir -c 10 -j 4 input.csv
 
+    qsv split outdir -s 100 --filter "gzip $FILE" input.csv
+    # This will create files with names like 0.csv, 100.csv, etc. in the directory
+    # 'outdir', and then run the command "gzip" on each chunk.
+
+    qsv split outdir --filter "powershell Compress-Archive -Path $FILE -Destination {}.zip" input.csv
+    # WINDOWS: This will create files with names like 0.zip, 100.zip, etc. in the directory
+    # 'outdir', and then run the command "Compress-Archive" on each chunk.
+
 For more examples, see https://github.com/dathere/qsv/blob/master/tests/test_split.rs.
 
 Usage:
@@ -88,7 +96,21 @@ split options:
                            [default: {}.csv]
     --pad <arg>            The zero padding width that is used in the
                            generated filename.
-                           [default: 0] 
+                           [default: 0]
+
+                            FILTER OPTIONS:
+    --filter <command>      Run the specified command on each chunk after it is written.
+                            The command should use the FILE environment variable
+                            ($FILE on Linux/macOS, %FILE% on Windows), which is
+                            set to the path of the output file for each chunk.
+                            The string '{}' in the command will be replaced by the
+                            zero-based row number of the first row in the chunk.
+    --filter-cleanup        Cleanup the original output filename AFTER the filter command
+                            is run successfully for EACH chunk. If the filter command is not
+                            successful, the original filename is not removed.
+                            Only valid when --filter is used.
+    --filter-ignore-errors  Ignore errors when running the filter command.
+                            Only valid when --filter is used.
 
 Common options:
     -h, --help             Display this message
@@ -100,8 +122,10 @@ Common options:
     -q, --quiet            Do not display an output summary to stderr.
 "#;
 
-use std::{fs, io, path::Path};
+use std::{fs, io, path::Path, process::Command};
 
+use dunce;
+use log::{debug, error};
 use rayon::iter::{IntoParallelIterator, ParallelIterator};
 use serde::Deserialize;
 
@@ -114,21 +138,24 @@ use crate::{
 
 #[derive(Clone, Deserialize)]
 struct Args {
-    arg_input:       Option<String>,
-    arg_outdir:      String,
-    flag_size:       usize,
-    flag_chunks:     Option<usize>,
-    flag_kb_size:    Option<usize>,
-    flag_jobs:       Option<usize>,
-    flag_filename:   FilenameTemplate,
-    flag_pad:        usize,
-    flag_no_headers: bool,
-    flag_delimiter:  Option<Delimiter>,
-    flag_quiet:      bool,
+    arg_input:                 Option<String>,
+    arg_outdir:                String,
+    flag_size:                 usize,
+    flag_chunks:               Option<usize>,
+    flag_kb_size:              Option<usize>,
+    flag_jobs:                 Option<usize>,
+    flag_filename:             FilenameTemplate,
+    flag_pad:                  usize,
+    flag_no_headers:           bool,
+    flag_delimiter:            Option<Delimiter>,
+    flag_quiet:                bool,
+    flag_filter:               Option<String>,
+    flag_filter_cleanup:       bool,
+    flag_filter_ignore_errors: bool,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
-    let args: Args = util::get_args(USAGE, argv)?;
+    let mut args: Args = util::get_args(USAGE, argv)?;
     if args.flag_size == 0 {
         return fail_incorrectusage_clierror!("--size must be greater than 0.");
     }
@@ -140,6 +167,30 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     fs::create_dir_all(&args.arg_outdir)?;
 
+    // if no input file is provided, use stdin and save to a temp file
+    if args.arg_input.is_none() {
+        // Get or initialize temp directory that persists until program exit
+        let temp_dir =
+            crate::config::TEMP_FILE_DIR.get_or_init(|| tempfile::TempDir::new().unwrap().keep());
+
+        // Create a temporary file with .csv extension to store stdin input
+        let mut temp_file = tempfile::Builder::new()
+            .suffix(".csv")
+            .tempfile_in(temp_dir)?;
+        io::copy(&mut io::stdin(), &mut temp_file)?;
+
+        // Get path as string, unwrap is safe as temp files are always valid UTF-8
+        let temp_path = temp_file.path().to_str().unwrap().to_string();
+
+        // Keep temp file from being deleted when it goes out of scope
+        // it will be deleted when the program exits when TEMP_FILE_DIR is deleted
+        temp_file
+            .keep()
+            .map_err(|e| format!("Failed to keep temporary stdin file: {e}"))?;
+
+        args.arg_input = Some(temp_path);
+    }
+
     if let Some(kb_size) = args.flag_kb_size {
         args.split_by_kb_size(kb_size)
     } else {
@@ -170,6 +221,7 @@ impl Args {
         let mut wtr = self.new_writer(&headers, 0, self.flag_pad)?;
         let mut i = 0;
         let mut num_chunks = 0;
+        let mut chunk_start = 0; // Track the start index of current chunk
         let mut row = csv::ByteRecord::new();
         let chunk_size_bytes = chunk_size * 1024;
         let mut chunk_size_bytes_left = chunk_size_bytes - header_byte_size;
@@ -197,6 +249,11 @@ impl Args {
 
             if curr_size_bytes + next_size_bytes >= chunk_size_bytes_left {
                 wtr.flush()?;
+                // Run filter command if specified
+                if self.flag_filter.is_some() {
+                    self.run_filter_command(chunk_start, self.flag_pad)?;
+                }
+                chunk_start = i; // Set start index for next chunk
                 wtr = self.new_writer(&headers, i, self.flag_pad)?;
                 chunk_size_bytes_left = chunk_size_bytes - header_byte_size;
                 num_chunks += 1;
@@ -208,11 +265,15 @@ impl Args {
             }
         }
         wtr.flush()?;
+        // Run filter command for the last chunk if specified
+        if self.flag_filter.is_some() {
+            self.run_filter_command(chunk_start, self.flag_pad)?;
+        }
 
         if !self.flag_quiet {
             eprintln!(
                 "Wrote chunk/s to '{}'. Size/chunk: <= {}KB; Num chunks: {}",
-                Path::new(&self.arg_outdir).canonicalize()?.display(),
+                dunce::canonicalize(Path::new(&self.arg_outdir))?.display(),
                 chunk_size,
                 num_chunks + 1
             );
@@ -239,12 +300,16 @@ impl Args {
         };
 
         let mut wtr = self.new_writer(&headers, 0, self.flag_pad)?;
-        let mut i = 0;
+        let mut i: usize = 0;
         let mut nchunks: usize = 0;
         let mut row = csv::ByteRecord::new();
         while rdr.read_byte_record(&mut row)? {
-            if i > 0 && i % chunk_size == 0 {
+            if i > 0 && i.is_multiple_of(chunk_size) {
                 wtr.flush()?;
+                // Run filter command if specified
+                if self.flag_filter.is_some() {
+                    self.run_filter_command(i - chunk_size, self.flag_pad)?;
+                }
                 nchunks += 1;
                 wtr = self.new_writer(&headers, i, self.flag_pad)?;
             }
@@ -252,12 +317,18 @@ impl Args {
             i += 1;
         }
         wtr.flush()?;
+        // Run filter command for the last chunk if specified
+        if self.flag_filter.is_some() {
+            // Calculate the start index for the last chunk
+            let last_chunk_start = ((i - 1) / chunk_size) * chunk_size;
+            self.run_filter_command(last_chunk_start, self.flag_pad)?;
+        }
 
         if !self.flag_quiet {
             eprintln!(
                 "Wrote {} chunk/s to '{}'. Rows/chunk: {} Num records: {}",
                 nchunks + 1,
-                Path::new(&self.arg_outdir).canonicalize()?.display(),
+                dunce::canonicalize(Path::new(&self.arg_outdir))?.display(),
                 chunk_size,
                 i
             );
@@ -312,13 +383,21 @@ impl Args {
             // safety: safe to unwrap because we know the writer is a file
             // the only way this can fail is if we cannot write to the file
             wtr.flush().unwrap();
+
+            // Run filter command if specified
+            if self.flag_filter.is_some() {
+                // We can't use ? here because we're in a closure
+                if let Err(e) = self.run_filter_command(i * chunk_size, self.flag_pad) {
+                    eprintln!("Error running filter command: {e}");
+                }
+            }
         });
 
         if !self.flag_quiet {
             eprintln!(
                 "Wrote {} chunk/s to '{}'. Rows/chunk: {} Num records: {}",
                 nchunks,
-                Path::new(&self.arg_outdir).canonicalize()?.display(),
+                dunce::canonicalize(Path::new(&self.arg_outdir))?.display(),
                 chunk_size,
                 idx_count
             );
@@ -343,6 +422,100 @@ impl Args {
         Ok(wtr)
     }
 
+    fn run_filter_command(&self, start: usize, width: usize) -> CliResult<()> {
+        if let Some(ref filter_cmd) = self.flag_filter {
+            let outdir = Path::new(&self.arg_outdir).canonicalize()?;
+            let filename = self.flag_filename.filename(&format!("{start:0>width$}"));
+            let file_path = outdir.join(&filename);
+
+            debug!(
+                "Processing filter command for file: {}",
+                file_path.display()
+            );
+
+            // Check if the file exists before running the filter command
+            if !file_path.exists() {
+                wwarn!(
+                    "File {} does not exist, skipping filter command",
+                    file_path.display()
+                );
+                return Ok(());
+            }
+
+            // Replace {} in the command with the start index
+            let cmd = filter_cmd.replace("{}", &format!("{start:0>width$}"));
+            debug!("Filter command template: {cmd}");
+
+            // Use dunce to get a canonicalized path that works well on Windows
+            // on non-Windows systems, its equivalent to std::fs::canonicalize
+            let canonical_path = match dunce::canonicalize(&file_path) {
+                Ok(path) => path,
+                Err(e) => {
+                    return fail_clierror!(
+                        "Failed to canonicalize path {}: {e}",
+                        file_path.display()
+                    );
+                },
+            };
+
+            let path_str = canonical_path.to_string_lossy().to_string();
+            debug!("Canonicalized path: {path_str}");
+
+            let canonical_outdir = match dunce::canonicalize(&outdir) {
+                Ok(path) => path,
+                Err(e) => {
+                    return fail_clierror!(
+                        "Failed to canonicalize outdir path {}: {e}",
+                        outdir.display()
+                    );
+                },
+            };
+
+            // Execute the command using the appropriate shell based on platform
+            let status = if cfg!(windows) {
+                debug!("Running Windows command: cmd /C {cmd}");
+                let cmd_vec = cmd.split(' ').collect::<Vec<&str>>();
+                Command::new("cmd")
+                    .arg("/C")
+                    .args(&cmd_vec)
+                    .current_dir(&canonical_outdir)
+                    .env("FILE", path_str)
+                    .status()
+            } else {
+                debug!("Running Unix command: sh -c {cmd}");
+                Command::new("sh")
+                    .arg("-c")
+                    .arg(&cmd)
+                    .current_dir(&canonical_outdir)
+                    .env("FILE", path_str)
+                    .status()
+            };
+
+            let status = match status {
+                Ok(status) => status,
+                Err(e) => {
+                    return fail_clierror!("Failed to execute filter command: {e}");
+                },
+            };
+
+            if !status.success() && !self.flag_filter_ignore_errors {
+                return fail_clierror!(
+                    "Filter command failed with exit code: {}",
+                    status.code().unwrap_or(-1)
+                );
+            }
+
+            // Cleanup the original output filename if the filter command was successful
+            if self.flag_filter_cleanup {
+                debug!("Cleaning up original file: {}", file_path.display());
+                if let Err(e) = fs::remove_file(&file_path) {
+                    wwarn!("Failed to remove file {}: {e}", file_path.display());
+                }
+            }
+        }
+        Ok(())
+    }
+
     fn rconfig(&self) -> Config {
         Config::new(self.arg_input.as_ref())
             .delimiter(self.flag_delimiter)
