@@ -1,7 +1,8 @@
 static USAGE: &str = r#"
-Convert CSV files to PostgreSQL, SQLite, XLSX and Data Package.
+Convert CSV files to PostgreSQL, SQLite, Excel XLSX, ODS, Parquet and Data Package.
 
-POSTGRES
+POSTGRESQL
+==========
 To convert to postgres you need to supply connection string.
 The format is described here - https://docs.rs/postgres/latest/postgres/config/struct.Config.html#examples-1.
 Additionally you can use `env=MY_ENV_VAR` and qsv will get the connection string from the
@@ -51,6 +52,7 @@ Print dump to stdout.
 
 
 SQLITE
+======
 Convert to sqlite db file. Will be created if it does not exist.
 
 If using the `--dump` option, instead of a sqlite database file, put the name of the dump file or `-` for stdout.
@@ -87,7 +89,8 @@ Print dump to stdout.
   $ qsv to sqlite --dump - file1.csv file2.csv
 
 
-XLSX
+EXCEL XLSX
+==========
 Convert to new xlsx file.
 
 Example:
@@ -106,7 +109,55 @@ Load files listed in the 'ourdata.infile-list' into xlsx file.
 
     $ qsv to xlsx output.xlsx ourdata.infile-list
 
-DATAPACKAGE
+ODS
+===
+Convert to new ODS (Open Document Spreadsheet) file.
+
+Example:
+
+Load `file1.csv` and `file2.csv' into ODS file.
+Will create `output.ods`, creating new sheets for each file, with the sheet name being the
+filename without the extension. Note the `output.ods` will be overwritten if it exists.
+
+  $ qsv to ods output.ods file1.csv file2.csv
+
+Load all files in dir1 into ODS file.
+
+    $ qsv to ods output.ods dir1
+
+Load files listed in the 'ourdata.infile-list' into ODS file.
+
+    $ qsv to ods output.ods ourdata.infile-list
+
+PARQUET
+=======
+Convert to directory of parquet files.  Need to select a directory, it will be created if it does not exists.
+If the `to_parquet` feature is not enabled, a simpler parquet conversion is available using the `sqlp`
+subcommand with the `--format parquet` option.
+
+To stream the data use the `pipe` option.  To pipe from stdin use `-` for the filename or use named pipe.
+Type guessing is more limited with this option.
+
+Examples:
+
+Convert `file1.csv` and `file2.csv' into `mydir/file1.parquet` and `mydir/file2.parquet` files.
+
+    $ qsv to parquet mydir file1.csv file2.csv
+
+Convert from stdin.
+
+    $ qsv to parquet --pipe mydir -
+
+Convert all files in dir1 into parquet files in myparquetdir.
+
+    $ qsv to parquet myparquetdir dir1
+
+Convert files listed in the 'data.infile-list' into parquet files in myparquetdir.
+    
+        $ qsv to parquet myparquetdir data.infile-list
+        
+DATA PACKAGE
+============
 Generate a datapackage, which contains stats and information about what is in the CSV files.
 
 Examples:
@@ -137,6 +188,8 @@ Usage:
     qsv to postgres [options] <postgres> [<input>...]
     qsv to sqlite [options] <sqlite> [<input>...]
     qsv to xlsx [options] <xlsx> [<input>...]
+    qsv to ods [options] <ods> [<input>...]
+    qsv to parquet [options] <parquet> [<input>...]
     qsv to datapackage [options] <datapackage> [<input>...]
     qsv to --help
 
@@ -149,9 +202,10 @@ To options:
     -s --schema <arg>      The schema to load the data into. (postgres only).
     -d --drop              Drop tables before loading new data into them (postgres/sqlite only).
     -e --evolve            If loading into existing db, alter existing tables so that new data will load. (postgres/sqlite only).
-    -i --pipe              Allow piping from stdin (using `-`) or from a named pipe.
+    -i --pipe              For parquet, allow piping from stdin (using `-`) or from a named pipe.
     -p --separator <arg>   For xlsx, use this character to help truncate xlsx sheet names.
                            Defaults to space.
+    -A --all-strings       Convert all fields to strings.
     -j, --jobs <arg>       The number of jobs to run in parallel.
                            When not set, the number of jobs is set to the number of CPUs detected.
                            
@@ -164,8 +218,9 @@ Common options:
 use std::{io::Write, path::PathBuf};
 
 use csvs_convert::{
-    DescribeOptions, Options, csvs_to_postgres_with_options, csvs_to_sqlite_with_options,
-    csvs_to_xlsx_with_options, make_datapackage,
+    DescribeOptions, Options, csvs_to_ods_with_options, csvs_to_parquet_with_options,
+    csvs_to_postgres_with_options, csvs_to_sqlite_with_options, csvs_to_xlsx_with_options,
+    make_datapackage,
 };
 use log::debug;
 use serde::Deserialize;
@@ -184,14 +239,19 @@ struct Args {
     arg_postgres:       Option<String>,
     cmd_sqlite:         bool,
     arg_sqlite:         Option<String>,
+    cmd_parquet:        bool,
+    arg_parquet:        Option<String>,
     cmd_xlsx:           bool,
     arg_xlsx:           Option<String>,
+    cmd_ods:            bool,
+    arg_ods:            Option<String>,
     cmd_datapackage:    bool,
     arg_datapackage:    Option<String>,
     arg_input:          Vec<PathBuf>,
     flag_delimiter:     Option<Delimiter>,
     flag_schema:        Option<String>,
     flag_separator:     Option<String>,
+    flag_all_strings:   bool,
     flag_dump:          bool,
     flag_drop:          bool,
     flag_evolve:        bool,
@@ -225,6 +285,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .delimiter(args.flag_delimiter.map(config::Delimiter::as_byte))
         .schema(args.flag_schema.unwrap_or_default())
         .seperator(args.flag_separator.unwrap_or_else(|| " ".into()))
+        .all_strings(args.flag_all_strings)
         .evolve(args.flag_evolve)
         .stats(args.flag_stats)
         .pipe(args.flag_pipe)
@@ -238,7 +299,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let tmpdir = tempfile::tempdir()?;
 
     if args.cmd_postgres {
-        debug!("converting to postgres");
+        debug!("converting to PostgreSQL");
         arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
         if args.flag_dump {
             options.dump_file = args.arg_postgres.expect("checked above");
@@ -250,9 +311,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 options,
             )?;
         }
-        debug!("conversion to postgres complete");
+        debug!("conversion to PostgreSQL complete");
     } else if args.cmd_sqlite {
-        debug!("converting to sqlite");
+        debug!("converting to SQLite");
         arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
         if args.flag_dump {
             options.dump_file = args.arg_sqlite.expect("checked above");
@@ -264,16 +325,32 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 options,
             )?;
         }
-        debug!("conversion to sqlite complete");
+        debug!("conversion to SQLite complete");
+    } else if args.cmd_parquet {
+        debug!("converting to Parquet");
+        arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
+        output = csvs_to_parquet_with_options(
+            args.arg_parquet.expect("checked above"),
+            arg_input,
+            options,
+        )?;
+        debug!("conversion to Parquet complete");
     } else if args.cmd_xlsx {
-        debug!("converting to xlsx");
+        debug!("converting to Excel XLSX");
         arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
 
         output =
             csvs_to_xlsx_with_options(args.arg_xlsx.expect("checked above"), arg_input, options)?;
-        debug!("conversion to xlsx complete");
+        debug!("conversion to Excel XLSX complete");
+    } else if args.cmd_ods {
+        debug!("converting to ODS");
+        arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
+
+        output =
+            csvs_to_ods_with_options(args.arg_ods.expect("checked above"), arg_input, options)?;
+        debug!("conversion to ODS complete");
     } else if args.cmd_datapackage {
-        debug!("creating datapackage");
+        debug!("creating Data Package");
         arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
 
         let describe_options = DescribeOptions::builder()
@@ -284,10 +361,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         output = make_datapackage(arg_input, PathBuf::new(), &describe_options.build())?;
         let file = std::fs::File::create(args.arg_datapackage.expect("checked above"))?;
         serde_json::to_writer_pretty(file, &output)?;
-        debug!("datapackage complete");
+        debug!("Data Package complete");
     } else {
         return fail_clierror!(
-            "Need to supply either xlsx,postgres,sqlite,datapackage as subcommand"
+            "Need to supply either xlsx, ods, parquet, postgres, sqlite, datapackage as subcommand"
         );
     }
 
