@@ -14,7 +14,7 @@ fn apply_ops_unknown_operation() {
         .arg("data.csv");
 
     let got: String = wrk.output_stderr(&mut cmd);
-    similar_asserts::assert_eq!(&*got, "usage error: Unknown 'obfuscate' operation\n")
+    assert_eq!(&*got, "usage error: Unknown 'obfuscate' operation\n")
 }
 
 #[test]
@@ -44,7 +44,7 @@ fn apply_ops_upper() {
         svec!["SUE", "BIRD"],
         svec!["HOPKINS", "JADE"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -99,7 +99,7 @@ fn apply_ops_gender_guess() {
         svec!["Abdurrahman", "Male"],
         svec!["Abbe", "NotSure"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -129,7 +129,7 @@ fn apply_ops_escape() {
         svec!["Sue", "Bird\\u{1f426}"],
         svec!["Hop\\u{119}kins", "J\\u{e6}de"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -161,7 +161,7 @@ fn apply_ops_upper_rename() {
         svec!["SUE", "BIRD"],
         svec!["HOPKINS", "JADE"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -186,7 +186,7 @@ fn apply_ops_upper_rename_invalid() {
         .arg("data.csv");
 
     let got: String = wrk.output_stderr(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         got,
         "usage error: Number of new columns does not match input column selection.\n"
     );
@@ -221,7 +221,7 @@ fn apply_ops_upper_index_params() {
         svec!["SUE", "BIRD"],
         svec!["HOPKINS", "JADE"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -259,7 +259,7 @@ fn apply_ops_encode62() {
         ],
         svec!["7671262618974725285", "98gSmJMD1XB", "7671262618974725285"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -298,7 +298,7 @@ fn apply_ops_decode62() {
             "encode62 error: ParseIntError { kind: InvalidDigit }"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -350,7 +350,7 @@ fn apply_ops_encode64() {
             "UnVzdO+8iOODqeOCueODiO+8ieOBr+S4puWIl+OBi+OBpOODnuODq+ODgeODkeODqeODgOOCpOODoOOBruODl+ODreOCsOODqeODn+ODs+OCsOiogOiqnuOBp+OBguOCiw=="],
 
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -397,7 +397,7 @@ fn apply_ops_decode64() {
             "UnVzdO+8iOODqeOCueODiO+8ieOBr+S4puWIl+OBi+OBpOODnuODq+ODgeODkeODqeODgOOCpOODoOOBruODl+ODreOCsOODqeODn+ODs+OCsOiogOiqnuOBp+OBguOCiw==",
             "Rust（ラスト）は並列かつマルチパラダイムのプログラミング言語である"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -467,7 +467,7 @@ fn apply_dynfmt() {
              strawberries, all 3 - is just worth it!"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -537,7 +537,7 @@ fn apply_dynfmt_keepcase() {
              strawberries, all 3 - is just worth it!"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -569,7 +569,7 @@ fn apply_dynfmt_issue1458() {
         svec!["Gordon", "H", "Irvin", "Sir/Madam Gordon H. Irvin"],
         svec!["Jack", "K", "Lynch", "Sir/Madam Jack K. Lynch"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -601,7 +601,7 @@ fn apply_regex_replace_issue1469() {
         svec!["Gordon", "H", "Irvin"],
         svec!["Jack", "K", "Lynch"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -637,7 +637,7 @@ fn apply_calcconv() {
         svec!["10", "bananas", "120", "0.50", "1.395600"],
         svec!["3", "strawberries", "20", "0.10", "0.069780"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -691,7 +691,7 @@ fn apply_calcconv_invalid() {
             "ERROR: Lexing error: Invalid string: bitcoins"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -727,7 +727,7 @@ fn apply_calcconv_units() {
         svec!["10", "bananas", "120", "0.50", "1.395600 WattHour"],
         svec!["3", "strawberries", "20", "0.10", "0.069780 WattHour"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -758,7 +758,7 @@ fn enum_apply_calconv_issue1458() {
         svec!["Jack", "K", "Lynch", "3"],
     ];
 
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     wrk.create("enum.csv", got);
 
@@ -780,7 +780,7 @@ fn enum_apply_calconv_issue1458() {
         svec!["Jack", "K", "Lynch", "3", "9"],
     ];
 
-    similar_asserts::assert_eq!(got2, expected2);
+    assert_eq!(got2, expected2);
 }
 
 #[test]
@@ -807,7 +807,7 @@ fn apply_ops_empty_shortcircuit() {
         svec!["0"],
         svec!["7"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -839,7 +839,7 @@ fn apply_ops_titlecase() {
         svec!["New York City Police Department - NYPD"],
         svec!["Department of Human Services"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -877,7 +877,7 @@ fn apply_ops_censor_check() {
         svec!["fluff truck", "false"],
         svec!["fukushima", "false"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -915,7 +915,7 @@ fn apply_ops_censor_count() {
         svec!["fluff truck", "0"],
         svec!["fukushima", "0"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -953,7 +953,7 @@ fn apply_ops_censor() {
         svec!["kiss my ass!", "kiss my ***!"],
         svec!["shittitties", "***********"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -999,7 +999,7 @@ fn apply_ops_censor_check_addlwords() {
         svec!["long john silver's shlong", "true"],
         svec!["Whoa! I see her cameltoe thru her athleisure!", "true"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1051,7 +1051,7 @@ fn apply_ops_censor_addlwords() {
             "ding **** the ***** is dead!"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1097,7 +1097,7 @@ fn apply_ops_censor_count_addlwords() {
         svec!["that cameltoe is so penistracting!", "2"],
         svec!["ding dong the bitch is dead!", "2"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1133,7 +1133,7 @@ fn apply_ops_replace() {
         svec!["Mr. Brown is not pleased."],
         svec!["this is a silverado car"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1156,7 +1156,7 @@ fn apply_ops_replace_validation_error() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         got,
         "usage error: --comparand (-C) and --replacement (-R) are required for replace \
          operation.\n"
@@ -1197,7 +1197,7 @@ fn apply_ops_regex_replace() {
         svec!["Won't fall for that scam!"],
         svec!["Just enter SSN when prompted. Also try SSN if it doesn't work."],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1220,7 +1220,7 @@ fn apply_ops_regex_replace_validation_error() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         got,
         "usage error: --comparand (-C) and --replacement (-R) are required for regex_replace \
          operation.\n"
@@ -1289,7 +1289,7 @@ fn apply_ops_mtrim() {
         svec!["Embedded (((multiple parens"],
         svec!["reverse parens"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1319,7 +1319,7 @@ fn apply_ops_chain() {
         svec!["MARY SUE"],
         svec!["HOPKINS"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1340,7 +1340,7 @@ fn apply_ops_chain_validation_error() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         got,
         "usage error: you can only use censor(0), copy(0), eudex(0), regex_replace(0), \
          replace(0), sentiment(0), similarity(2), strip(0), and whatlang(0) ONCE per operation \
@@ -1365,7 +1365,7 @@ fn apply_ops_chain_validation_error_missing_comparand() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    similar_asserts::assert_eq!(
+    assert_eq!(
         got,
         "usage error: --comparand (-C) and --new_column (-c) is required for similarity \
          operations.\n"
@@ -1400,7 +1400,7 @@ fn apply_ops_chain_squeeze0() {
         svec!["MARYSUE"],
         svec!["HOPKINS"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1430,7 +1430,7 @@ fn apply_ops_squeeze0() {
         svec!["MarySue"],
         svec!["JohnHopkins"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1462,7 +1462,7 @@ fn apply_ops_chain_strip() {
         svec!["MARY SUE"],
         svec!["HOPKINS"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1492,7 +1492,7 @@ fn apply_ops_mixed_case_chain() {
         svec!["MARY SUE"],
         svec!["HOPKINS"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1516,7 +1516,7 @@ fn apply_no_headers() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![svec!["JOHN"], svec!["MARY"], svec!["SUE"], svec!["HOPKINS"]];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1548,7 +1548,7 @@ fn apply_rename() {
         svec!["SUE"],
         svec!["HOPKINS"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1580,7 +1580,7 @@ fn apply_new_column() {
         svec!["Sue", "SUE"],
         svec!["Hopkins", "HOPKINS"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1628,7 +1628,7 @@ fn apply_ops_thousands() {
         svec!["-5"],
         svec!["not a number, should be ignored"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1665,7 +1665,7 @@ fn apply_ops_thousands_space() {
         svec!["5"],
         svec!["not a number, should be ignored"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1702,7 +1702,7 @@ fn apply_ops_thousands_indiancomma() {
         svec!["5"],
         svec!["not a number, should be ignored"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1742,7 +1742,7 @@ fn apply_ops_thousands_eurostyle() {
         svec!["5"],
         svec!["not a number, should be ignored"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1781,7 +1781,7 @@ fn apply_ops_thousands_hexfour() {
         svec!["5"],
         svec!["not a number, should be ignored"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1833,7 +1833,7 @@ fn apply_ops_round() {
         svec!["-5"],
         svec!["not a number, should be ignored"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1874,7 +1874,7 @@ fn apply_ops_round_5places() {
         svec!["5"],
         svec!["not a number, should be ignored"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1976,7 +1976,7 @@ fn apply_ops_currencytonum() {
         svec!["10.78"],
         svec!["10.78"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2082,7 +2082,7 @@ fn apply_ops_currencytonum_strict() {
         svec!["10.78"],
         svec!["10.78"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2172,7 +2172,7 @@ fn apply_ops_numtocurrency() {
         svec!["$10.78"],
         svec!["$10.78"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2224,7 +2224,7 @@ fn apply_ops_numtocurrency_convert() {
         svec!["EUR 149,999.25"],
         svec!["EUR 451,499.32"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2278,7 +2278,7 @@ fn apply_ops_numtocurrency_convert_euro_format() {
         svec!["EUR 149.999,25"],
         svec!["EUR 451.499,32"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2312,7 +2312,7 @@ fn apply_ops_similarity() {
         svec!["Edna", "0.0"],
         svec!["Larry", "0.0"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2348,7 +2348,7 @@ fn apply_ops_similarity_eudex() {
         svec!["Larry", "false"],
         svec!["Joel", "false"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2386,7 +2386,7 @@ fn apply_ops_similarity_more_eudex() {
         svec!["Michael", "false"],
         svec!["Jingjing", "false"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2433,7 +2433,7 @@ fn apply_ops_sentiment() {
         svec!["5 stars! Highly recommended!", "0.3973495344831422"],
         svec!["What were they thinking!?!", "-0.19353437967075598"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2519,7 +2519,7 @@ fn apply_ops_whatlang() {
             "Tgl"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2607,7 +2607,7 @@ fn apply_ops_whatlang_high_confidence_threshold() {
             "Tgl(1.000)"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2695,7 +2695,7 @@ fn apply_ops_whatlang_low_confidence_threshold() {
             "Tgl"
         ],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2726,7 +2726,7 @@ fn apply_emptyreplace() {
         svec!["Sue"],
         svec!["Hopkins"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2757,7 +2757,7 @@ fn apply_emptyreplace_multiple_columns() {
         svec!["Sue", "NA", "Boston"],
         svec!["Hopkins", "40", "NA"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2788,7 +2788,7 @@ fn apply_emptyreplace_all_columns() {
         svec!["Sue", "NA", "Boston"],
         svec!["Hopkins", "40", "NA"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2824,5 +2824,5 @@ fn apply_crc32() {
         ],
     ];
 
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
