@@ -27,7 +27,7 @@ fn luau_map() {
         svec!["c", "72", "73"],
         svec!["d", "7", "8"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -57,7 +57,7 @@ fn luau_map_multiple_columns() {
         svec!["c", "72", "73", "74", "75"],
         svec!["d", "7", "8", "9", "10"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -87,7 +87,7 @@ fn luau_map_idx() {
         svec!["c", "72", "216"],
         svec!["d", "7", "28"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -117,7 +117,7 @@ fn luau_aggregation() {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -149,7 +149,7 @@ fn luau_aggregation_with_begin() {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -183,11 +183,11 @@ fn luau_aggregation_with_begin_end() {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 275\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -224,11 +224,11 @@ fn luau_aggregation_with_embedded_begin_end() {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 275\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -312,11 +312,11 @@ END {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 116 adjusted: 145\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -429,7 +429,7 @@ END {
         svec!["b", "24", "107.12"],
         svec!["a", "13", "120.64"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7.28/74.88 Grand total of 4 rows: 120.64\n";
@@ -438,6 +438,11 @@ END {
     wrk.assert_success(&mut cmd);
 }
 
+// TODO: Ignore this test on Windows for now.
+// Multiple attempts to fix this test on Windows
+// have not been successful. The error is related to a file open
+// issue, which is not easily reproducible.
+#[cfg(not(target_os = "windows"))]
 #[test]
 fn luau_register_lookup_table_on_url() {
     let wrk = Workdir::new("luau_register_lookup_table_on_url");
@@ -528,7 +533,7 @@ END {
         svec!["b", "24", "107.12"],
         svec!["a", "13", "120.64"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7.28/74.88 Grand total of 4 rows: 120.64\n";
@@ -624,7 +629,7 @@ END {
         svec!["b", "24", "107.12"],
         svec!["a", "13", "120.64"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7.28/74.88 Grand total of 4 rows: 120.64\n";
@@ -634,7 +639,7 @@ END {
 }
 
 #[test]
-// #[ignore = "Temporarily skip this as Boston CityScore Summary is currently unavailable"]
+#[ignore = "Temporarily skip this as Boston CityScore Summary is currently unavailable"]
 fn luau_register_lookup_table_ckan() {
     let wrk = Workdir::new("luau_register_lookup_ckan");
     wrk.create(
@@ -807,12 +812,12 @@ END {
         svec!["a", "13", "13"],
         svec!["b", "24", "37"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end =
         "This is the break msg.\nMin/Max: 13/24 Grand total of 2 rows: 50\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -878,11 +883,11 @@ END {
         svec!["b", "24", "37"],
         svec!["d", "7", "44"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 0/24 Grand total of 3 rows: 94\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -945,11 +950,11 @@ END {
         svec!["c", "72", "charlie"],
         svec!["d", "7", "delta"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "4 rows\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1016,15 +1021,15 @@ END {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 3 rows: 275\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     let table_txt = wrk.read_to_string("count.txt").unwrap();
     let expected_table_txt = "4\n";
-    similar_asserts::assert_eq!(table_txt, expected_table_txt);
+    assert_eq!(table_txt, expected_table_txt);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1154,11 +1159,11 @@ END {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let echo_text = wrk.read_to_string("echo.txt").unwrap();
     let expected_echo_text = "the quick brown fox jumped over the lazy dog";
-    similar_asserts::assert_eq!(
+    assert_eq!(
         dos2unix(&echo_text).trim_end(),
         dos2unix(expected_echo_text).trim_end()
     );
@@ -1235,11 +1240,11 @@ END {
         svec!["d4", "74", "275"],
         svec!["Grand Total", "", "275"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 275\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1323,11 +1328,11 @@ END {
         svec!["a0", "130", "305"],
         svec!["Grand Total", "", "305"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 305\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1385,11 +1390,11 @@ END {
         svec!["c", "1", "10"],
         svec!["d", "5", "15"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "The lock combination is 2715. Again, 2, 7, 1, 5.\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1436,11 +1441,11 @@ fn luau_aggregation_with_embedded_begin_end_and_beginend_options() {
         svec!["c", "72", "110"],
         svec!["d", "7", "117"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Minimum/Maximum: 7/72 Grand total of 4 rows: 279\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1521,11 +1526,11 @@ END {
         svec!["b", "24", "103"],
         svec!["a", "13", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 305\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1615,11 +1620,11 @@ END {
         svec!["b", "24", "103"],
         svec!["a", "13", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max/Range: 7/72/65 Grand total of 4 rows: 305\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1705,11 +1710,11 @@ END {
         svec!["b", "24", "103", "113.3"],
         svec!["a", "13", "116", "127.6"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: 7/72 Grand total of 4 rows: 305\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1745,11 +1750,11 @@ fn luau_aggregation_with_begin_end_and_luau_syntax() {
         svec!["c", "-72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let end = wrk.output_stderr(&mut cmd);
     let expected_end = "Min/Max: -72/13 Grand total of 4 rows: 275\n".to_string();
-    similar_asserts::assert_eq!(end, expected_end);
+    assert_eq!(end, expected_end);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1782,7 +1787,7 @@ fn luau_map_remap_with_qsv_coalesce() {
         svec!["3", "Aramais E. Aghabekyan"],
         svec!["4", "Eleonora V. Avanesyan"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     wrk.assert_success(&mut cmd);
 }
@@ -1814,7 +1819,7 @@ fn luau_map_math() {
         svec!["c", "72", "36"],
         svec!["d", "7", "3"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1844,7 +1849,7 @@ fn luau_map_require_luadate() {
         svec!["c", "72", "2008-11-04", "2009-01-15T00:00:00"],
         svec!["d", "7", "2020-03-11", "2020-03-18T00:00:00"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1890,7 +1895,7 @@ return mintest"#;
         svec!["c", "72", "42", "42"],
         svec!["d", "7", "6.5", "6.5"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1944,7 +1949,7 @@ fn luau_map_header_with_nonalphanumeric_chars() {
         svec!["c", "72", "c36"],
         svec!["d", "7", "d3"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -1972,7 +1977,7 @@ fn luau_map_no_headers() {
         svec!["c", "72", "73"],
         svec!["d", "7", "8"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2000,7 +2005,7 @@ fn luau_map_no_headers_multiple_new_columns() {
         svec!["c", "72", "73", "74", "75"],
         svec!["d", "7", "8", "9", "10"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2030,7 +2035,7 @@ fn luau_map_exec() {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2060,7 +2065,7 @@ fn luau_map_exec_long_column_names() {
         svec!["c", "72", "109"],
         svec!["d", "7", "116"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2092,7 +2097,7 @@ fn luau_map_no_globals() {
         svec!["3", "72", "4"],
         svec!["4", "7", "5"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2122,7 +2127,7 @@ fn luau_map_boolean() {
         svec!["c", "72", "true"],
         svec!["d", "7", "false"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2149,7 +2154,7 @@ fn luau_filter() {
         svec!["b", "24"],
         svec!["c", "72"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2178,7 +2183,7 @@ fn luau_filter_error() {
         svec!["c", "72"],
         svec!["d", "7"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2216,7 +2221,7 @@ fn luau_filter_num() {
         svec!["i", "0.000123"],
         svec!["j", "-7.01"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2258,7 +2263,7 @@ return tonumber(number) > tonumber(limit)
         .arg("data.csv");
 
     let testenvvar = std::env::var("TESTENVVAR").unwrap_or_else(|_| "NOT SET".to_string());
-    similar_asserts::assert_eq!(testenvvar, "NOT SET");
+    assert_eq!(testenvvar, "NOT SET");
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![
@@ -2268,7 +2273,7 @@ return tonumber(number) > tonumber(limit)
         svec!["c", "72"],
         svec!["f", "42"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2314,7 +2319,7 @@ return tonumber(number) > tonumber(limit)
         svec!["c", "72"],
         svec!["f", "42"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2363,7 +2368,7 @@ return config_tbl["string"] .. " " .. config_tbl["object"]["nested"] .. " " .. t
         svec!["b", "hello value 42"],
         svec!["c", "hello value 42"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2408,7 +2413,7 @@ return users[idx]["name"]
         svec!["2", "Bob"],
         svec!["3", "Charlie"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2499,7 +2504,7 @@ fn luau_cumsum_single() {
         svec!["40", "100"],
         svec!["50", "150"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2542,7 +2547,7 @@ fn luau_cumsum_multiple() {
         svec!["150", "80", "450", "205", "245"],
         svec!["300", "100", "750", "305", "445"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2575,7 +2580,7 @@ fn luau_cumsum_invalid_input() {
         svec!["bad", "30"], // Invalid input treated as 0
         svec!["30", "60"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2606,7 +2611,7 @@ fn luau_cumprod() {
         svec!["4", "24"],
         svec!["5", "120"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2639,7 +2644,7 @@ fn luau_cummax_cummin() {
         svec!["3", "15", "3"],
         svec!["12", "15", "3"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2677,7 +2682,7 @@ fn luau_lag() {
         svec!["40", "30", "20"],
         svec!["50", "40", "30"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2715,7 +2720,7 @@ fn luau_cumany_cumall() {
         svec!["0", "true", "false"],
         svec!["20", "true", "false"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2753,7 +2758,7 @@ fn luau_diff() {
         svec!["20", "7", "5"],
         svec!["18", "-2", "5"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2789,7 +2794,7 @@ fn luau_cumany_cumall_with_strings() {
         svec!["world", "true", "false"],
         svec!["", "true", "false"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2820,7 +2825,7 @@ fn luau_cumall_with_numbers() {
         svec!["20", "false"],
         svec!["30", "false"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2856,7 +2861,7 @@ fn luau_lag_with_default() {
         svec!["30", "20", "10"],
         svec!["40", "30", "20"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2893,7 +2898,7 @@ fn luau_diff_with_lag() {
         svec!["115", "-5", "15", "-4.2%"],
         svec!["140", "25", "20", "21.7%"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2932,7 +2937,7 @@ fn luau_cumulative_stats() {
         svec!["5", "25", "5", "55"],
         svec!["20", "25", "5", "75"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -2979,7 +2984,7 @@ return "ok"
 
     // Verify the compact JSON output
     let json_content = std::fs::read_to_string(wrk.path("output.json")).unwrap();
-    similar_asserts::assert_eq!(
+    assert_eq!(
         json_content,
         r#"{"numbers":[13,24,72,7],"nested":{"key":"value","array":[1,2,3]},"letters":["a","b","c","d"]}"#
     );
@@ -3009,7 +3014,7 @@ return "ok"
   ]
 }"#;
 
-    similar_asserts::assert_eq!(pretty_content, expected);
+    assert_eq!(pretty_content, expected);
 }
 
 #[test]
@@ -3052,13 +3057,13 @@ return "ok"
     let json: serde_json::Value = serde_json::from_str(&json_content).unwrap();
 
     assert!(json["null_value"].is_null());
-    similar_asserts::assert_eq!(json["boolean_true"], json!(true));
-    similar_asserts::assert_eq!(json["boolean_false"], json!(false));
-    similar_asserts::assert_eq!(json["number_integer"], json!(42));
-    similar_asserts::assert_eq!(json["number_float"], json!(3.14));
-    similar_asserts::assert_eq!(json["empty_string"], json!(""));
-    similar_asserts::assert_eq!(json["empty_table"], json!({}));
-    similar_asserts::assert_eq!(json["nested_empty"]["empty"], json!({}));
+    assert_eq!(json["boolean_true"], json!(true));
+    assert_eq!(json["boolean_false"], json!(false));
+    assert_eq!(json["number_integer"], json!(42));
+    assert_eq!(json["number_float"], json!(3.14));
+    assert_eq!(json["empty_string"], json!(""));
+    assert_eq!(json["empty_table"], json!({}));
+    assert_eq!(json["nested_empty"]["empty"], json!({}));
 }
 
 #[test]
@@ -3103,7 +3108,7 @@ return qsv_accumulate(value, weighted_sum, 0)
         svec!["40", "300"], // 140 + 40 * 4
         svec!["50", "550"], // 300 + 50 * 5
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -3148,7 +3153,7 @@ return qsv_accumulate(value, weighted_sum)
         svec!["40", "310"], // 150 + 40 * 4
         svec!["50", "560"], // 310 + 50 * 5
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -3197,7 +3202,7 @@ return accumulated
         svec!["40", "200"], // 160 + 40
         svec!["50", "250"], // 200 + 50
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -3247,7 +3252,7 @@ return qsv_accumulate(value, func_with_reset, 0)
         svec!["4", "4"], // reset since 8 > 7
         svec!["1", "5"], // 4 + 1
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -3271,7 +3276,7 @@ fn luau_cumsum_overflow() {
     wrk.assert_err(&mut cmd);
     let stderr = wrk.output_stderr(&mut cmd);
     let expected = "Luau errors encountered: 1\n";
-    similar_asserts::assert_eq!(stderr, expected);
+    assert_eq!(stderr, expected);
 }
 
 #[test]
